@@ -18,43 +18,67 @@
 
 # These global variables are declared to eliminate associated R CMD check warnings.
 # There is no other identified functional impact of these global declarations.
+# However, only variables defined in this package should be added to the list.
+# If R CMD check warns about undefined global functions or variables that are
+# from another package, they need to be added to this package's NAMESPACE.
 
 utils::globalVariables(
-  c(
-    ".",
+  c(".",
+    "analysis",
+    "asy_event",
+    "asy_n",
+    "asy_time",
+    "bound",
     "ex1_delayed_effect",
-    "N",
     "cte",
+    "cross_lower",
+    "cross_upper",
+    "cut_date",
     "dropout_rate",
     "dropout_time",
     "duration",
     "enroll_time",
     "event",
     "eventCount",
-    "events",
+    "event_total",
     "fail",
     "fail_time",
     "finish",
     "hr",
     "i",
     "lambda",
+    "lower",
+    "lower_bound",
     "max_weight",
     "mtte",
-    "n_event_tol",
-    "n_risk_tol",
+    "N",
+    "n",
+    "n_cross_lower",
+    "n_cross_upper",
+    "event_total",
+    "event_trt",
+    "n_risk_total",
     "n_risk_trt",
-    "nbrOfWorkers",
     "o_minus_e",
     "one",
     "origin",
     "period",
+    "probability",
     "rate",
     "s",
+    "sim_event",
+    "sim_id",
+    "sim_lower_prob",
+    "sim_n",
+    "sim_upper_prob",
+    "sim_time",
     "status",
     "stratum",
     "time",
     "treatment",
     "tte",
+    "upper",
+    "upper_bound",
     "v",
     "var_o_minus_e",
     "weight",
